@@ -28,8 +28,8 @@
 #include "../debug.h"
 #include "utils.h"
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
+#include <QNetworkRequest>
+#include <QNetworkReply>
 
 
 using namespace KGAPI2;
@@ -62,7 +62,7 @@ QNetworkRequest CalendarFetchJob::Private::createRequest(const QUrl& url)
     QStringList headers;
     const auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
+    for (const QByteArray &str : qAsConst(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
@@ -96,7 +96,7 @@ void CalendarFetchJob::start()
     } else {
         url = CalendarService::fetchCalendarUrl(d->calendarId);
     }
-    qDebug() << "CalendarFetchJob::url()" << CalendarService::fetchCalendarsUrl();
+    qCDebug(KGAPIRaw) << "CalendarFetchJob::url()" << CalendarService::fetchCalendarsUrl();
     const QNetworkRequest request = d->createRequest(url);
     enqueueRequest(request);
 }
