@@ -23,8 +23,8 @@
 #include "contactsgroup.h"
 #include "../debug.h"
 
-#include <QtXml/QDomDocument>
-#include <QtXml/QDomElement>
+#include <QDomDocument>
+#include <QDomElement>
 #include <QJsonDocument>
 
 /* Qt::escape() */
@@ -60,7 +60,7 @@ ObjectsList parseJSONFeed(const QByteArray& jsonFeed, FeedData& feedData)
     const QVariantMap head = document.toVariant().toMap();
     const QVariantMap feed = head.value(QStringLiteral("feed")).toMap();
     const QVariantList categories = feed.value(QStringLiteral("category")).toList();
-    Q_FOREACH(const QVariant &c, categories) {
+    for (const QVariant &c : categories) {
         const QVariantMap category = c.toMap();
         bool groups = false;
 
@@ -69,7 +69,7 @@ ObjectsList parseJSONFeed(const QByteArray& jsonFeed, FeedData& feedData)
         }
 
         const QVariantList entries = feed.value(QStringLiteral("entry")).toList();
-        Q_FOREACH(const QVariant &e, entries) {
+        for (const QVariant &e : entries) {
             if (groups) {
                 output << Private::JSONToContactsGroup(e.toMap());
             } else {
@@ -79,7 +79,7 @@ ObjectsList parseJSONFeed(const QByteArray& jsonFeed, FeedData& feedData)
     }
 
     const QVariantList links = feed.value(QStringLiteral("link")).toList();
-    Q_FOREACH(const QVariant &l, links) {
+    for (const QVariant &l : links) {
         const QVariantMap link = l.toMap();
         if (link.value(QStringLiteral("rel")).toString() == QLatin1String("next")) {
             feedData.nextPageUrl = QUrl(link.value(QStringLiteral("href")).toString());
@@ -267,7 +267,7 @@ ContactsGroupPtr JSONToContactsGroup(const QByteArray& jsonData)
     const QVariantList categories = entry.value(QStringLiteral("category")).toList();
 
     bool isGroup = false;
-    Q_FOREACH(const QVariant &c, categories) {
+    for (const QVariant &c : categories) {
         const QVariantMap category = c.toMap();
 
         if (category.value(QStringLiteral("term")).toString() == QLatin1String("http://schemas.google.com/contact/2008#group")) {
@@ -303,7 +303,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     /* Store URL of the picture. The URL will be used later by PhotoJob to fetch the picture
      * itself. */
     const QVariantList links = data.value(QStringLiteral("link")).toList();
-    Q_FOREACH(const QVariant &link, links) {
+    for (const QVariant &link : links) {
         const QVariantMap linkMap = link.toMap();
         if (linkMap.value(QStringLiteral("rel")).toString() == QLatin1String("http://schemas.google.com/contacts/2008/rel#photo")) {
             contact->setPhotoUrl(linkMap.value(QStringLiteral("href")).toString());
@@ -376,7 +376,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     /* Relationships */
     if (data.contains(QStringLiteral("gContact$relation"))) {
         const QVariantList relations = data.value(QStringLiteral("gContact$relation")).toList();
-        Q_FOREACH(const QVariant &r, relations) {
+        for (const QVariant &r : relations) {
             const QVariantMap relation = r.toMap();
             if (relation.value(QStringLiteral("rel")).toString() == QLatin1String("spouse")) {
                 contact->setSpousesName(relation.value(QStringLiteral("$t")).toString());
@@ -398,7 +398,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     /* Anniversary */
     if (data.contains(QStringLiteral("gContact$event"))) {
         const QVariantList events = data.value(QStringLiteral("gContact$event")).toList();
-        Q_FOREACH(const QVariant &e, events) {
+        for (const QVariant &e : events) {
             const QVariantMap event = e.toMap();
 
             if (event.value(QStringLiteral("rel")).toString() == QLatin1String("anniversary")) {
@@ -411,7 +411,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     /* Websites */
     if (data.contains(QStringLiteral("gContact$website"))) {
         const QVariantList websites = data.value(QStringLiteral("gContact$website")).toList();
-        Q_FOREACH(const QVariant &w, websites) {
+        for (const QVariant &w : websites) {
             const QVariantMap web = w.toMap();
 
             if (web.value(QStringLiteral("rel")).toString() == QLatin1String("home-page")) {
@@ -430,7 +430,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
 
     /* Emails */
     const QVariantList emails = data.value(QStringLiteral("gd$email")).toList();
-    Q_FOREACH(const QVariant & em, emails) {
+    for (const QVariant & em : emails) {
         const QVariantMap email = em.toMap();
         contact->insertEmail(email.value(QStringLiteral("address")).toString(),
                             email.value(QStringLiteral("primary")).toBool());
@@ -438,7 +438,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
 
     /* IMs */
     const QVariantList ims = data.value(QStringLiteral("gd$im")).toList();
-    Q_FOREACH(const QVariant & i, ims) {
+    for (const QVariant & i : ims) {
         const QVariantMap im = i.toMap();
         const QString protocol = Contact::IMSchemeToProtocolName(im.value(QStringLiteral("protocol")).toString());
         contact->insertCustom(QLatin1String("messaging/") + protocol,
@@ -448,7 +448,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
 
     /* Phone numbers */
     const QVariantList phones = data.value(QStringLiteral("gd$phoneNumber")).toList();
-    Q_FOREACH(const QVariant & p, phones) {
+    for (const QVariant & p : phones) {
         const QVariantMap phone = p.toMap();
         contact->insertPhoneNumber(KContacts::PhoneNumber(phone.value(QStringLiteral("$t")).toString(),
                                   Contact::phoneSchemeToType(phone.value(QStringLiteral("rel")).toString())));
@@ -456,7 +456,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
 
     /* Addresses */
     const QVariantList addresses = data.value(QStringLiteral("gd$structuredPostalAddress")).toList();
-    Q_FOREACH(const QVariant & a, addresses) {
+    for (const QVariant &a : addresses) {
         const QVariantMap address = a.toMap();
         KContacts::Address addr;
         if (!address.contains(QStringLiteral("gd$city")) &&
@@ -506,7 +506,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
 
     /* User-defined fields */
     const QVariantList userDefined = data.value(QStringLiteral("gContact$userDefinedField")).toList();
-    Q_FOREACH(const QVariant & u, userDefined) {
+    for (const QVariant & u : userDefined) {
         const QVariantMap field = u.toMap();
         contact->insertCustom(QStringLiteral("KADDRESSBOOK"),
                              field.value(QStringLiteral("key")).toString(),
@@ -516,7 +516,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     /* Groups */
     const QVariantList groups = data.value(QStringLiteral("gContact$groupMembershipInfo")).toList();
     QStringList groupsList;
-    Q_FOREACH(const QVariant & g, groups) {
+    for (const QVariant & g : groups) {
         const QVariantMap group = g.toMap();
         if (group.value(QStringLiteral("deleted")).toBool() == false) {
             groupsList.append(group.value(QStringLiteral("href")).toString());
@@ -536,7 +536,7 @@ ContactPtr JSONToContact(const QByteArray& jsonData)
     const QVariantList categories = entry.value(QStringLiteral("category")).toList();
 
     bool isContact = false;
-    Q_FOREACH(const QVariant &c, categories) {
+    for (const QVariant &c : categories) {
         const QVariantMap category = c.toMap();
 
         if (category.value(QStringLiteral("term")).toString() == QLatin1String("http://schemas.google.com/contact/2008#contact")) {
@@ -733,8 +733,8 @@ QByteArray contactToXML(const ContactPtr& contact)
 
     const QStringList groups = contact->custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','));
     qCDebug(KGAPIDebug) << groups;
-    if ((groups.length() > 0) && !groups.at(0).isEmpty()) {
-        Q_FOREACH(const QString & group, groups) {
+    if ((!groups.isEmpty()) && !groups.at(0).isEmpty()) {
+        for (const QString & group :groups) {
             bool removed = contact->groupIsDeleted(group);
             if (!removed)
                 output.append(QStringLiteral("<gContact:groupMembershipInfo deleted=\"false\" href=\"%2\" />").arg(group).toUtf8());
@@ -745,7 +745,7 @@ QByteArray contactToXML(const ContactPtr& contact)
     /* User-defined fields */
     const QStringList customs = contact->customs();
     const QString defined_str = QStringLiteral("<gContact:userDefinedField key=\"%1\" value=\"%2\" />");
-    Q_FOREACH(const QString &customStr, customs) {
+    for (const QString &customStr : customs) {
         QString key = customStr.left(customStr.indexOf(QLatin1Char(':')));
         if (!parsedCustoms.contains(key)) {
             if (key.startsWith(QLatin1String("KADDRESSBOOK-"))) {
@@ -784,7 +784,7 @@ ContactPtr XMLToContact(const QByteArray& xmlData)
     doc.setContent(xmlDoc);
     const QDomNodeList entry = doc.elementsByTagName(QStringLiteral("entry"));
     QDomNodeList data;
-    if (entry.length() > 0) {
+    if (!entry.isEmpty()) {
         data = entry.at(0).childNodes();
     } else {
         return ContactPtr();
@@ -1090,7 +1090,7 @@ ContactsGroupPtr XMLToContactsGroup(const QByteArray& xmlData)
     doc.setContent(xmlDoc);
     const QDomNodeList entry = doc.elementsByTagName(QStringLiteral("entry"));
     QDomNodeList data;
-    if (entry.length() > 0) {
+    if (!entry.isEmpty()) {
         data = entry.at(0).childNodes();
     } else {
         return ContactsGroupPtr();
