@@ -28,8 +28,8 @@
 #include "utils.h"
 
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
+#include <QNetworkRequest>
+#include <QNetworkReply>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
