@@ -27,7 +27,7 @@
 #include "deletejob.h"
 #include "kgapidrive_export.h"
 
-#include <QtCore/QStringList>
+#include <QStringList>
 
 namespace KGAPI2
 {
@@ -43,23 +43,23 @@ class KGAPIDRIVE_EXPORT ParentReferenceDeleteJob : public KGAPI2::DeleteJob
     explicit ParentReferenceDeleteJob(const QString &fileId,
                                       const QString &referenceId,
                                       const AccountPtr &account,
-                                      QObject *parent = 0);
+                                      QObject *parent = nullptr);
     explicit ParentReferenceDeleteJob(const QString &fileId,
                                       const QStringList &referencesIds,
                                       const AccountPtr &account,
-                                      QObject *parent = 0);
+                                      QObject *parent = nullptr);
     explicit ParentReferenceDeleteJob(const QString &fileId,
                                       const ParentReferencePtr &reference,
                                       const AccountPtr &account,
-                                      QObject *parent = 0);
+                                      QObject *parent = nullptr);
     explicit ParentReferenceDeleteJob(const QString &fileId,
                                       const ParentReferencesList &references,
                                       const AccountPtr &account,
-                                      QObject *parent = 0);
+                                      QObject *parent = nullptr);
     virtual ~ParentReferenceDeleteJob();
 
   protected:
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
   private:
     class Private;
